@@ -4,7 +4,7 @@
 # All rights reserved.
 #
 
-from connect.client import R
+from connect.client import R, ClientError
 
 from ..utils import convert_to_datetime, get_value
 
@@ -103,13 +103,16 @@ def search_product_primary(parameters):
 
 
 def get_primary_key(parameters, product_id, client, products_primary_keys):
-    if product_id not in products_primary_keys:
-        prod_parameters = client.collection('products')[product_id].collection('parameters').all()
-        primary_id = search_product_primary(prod_parameters)
-        products_primary_keys[product_id] = primary_id
-    for param in parameters:
-        if param['id'] == products_primary_keys[product_id]:
-            return param['value'] if 'value' in param and len(param['value']) > 0 else '-'
+    try:
+        if product_id not in products_primary_keys:
+            prod_parameters = client.collection('products')[product_id].collection('parameters').all()
+            primary_id = search_product_primary(prod_parameters)
+            products_primary_keys[product_id] = primary_id
+        for param in parameters:
+            if param['id'] == products_primary_keys[product_id]:
+                return param['value'] if 'value' in param and len(param['value']) > 0 else '-'
+    except ClientError:
+        pass
     return '-'
 
 
